/*
    SPDX-FileCopyrightText: 2020 Vlad Zahorodnii <vlad.zahorodnii@kde.org>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#include "plugin.h"

namespace KWin
{

Plugin::Plugin() = default;

PluginFactory::PluginFactory() = default;

} // namespace KWin

#include "moc_plugin.cpp"
